@@ -19,14 +19,15 @@ from concurrent.futures import Future
 from functools import partial
 from pathlib import Path
 from typing import Optional
+from unittest.mock import Mock
 
 import pytest
+
 from pygls.exceptions import JsonRpcException, JsonRpcInvalidParams
 from pygls.lsp import Model, get_method_params_type
 from pygls.lsp.types import ClientCapabilities, InitializeParams, InitializeResult
 from pygls.protocol import JsonRPCNotification, JsonRPCRequestMessage, JsonRPCResponseMessage
 from pygls.protocol import deserialize_message as _deserialize_message
-from pygls.protocol import to_lsp_name
 
 TEST_METHOD = 'test_method'
 
@@ -261,13 +262,20 @@ def test_initialize_should_return_server_capabilities(client_server):
         capabilities=ClientCapabilities(),
     )
 
-    server_capabilities = server.lsp.bf_initialize(params)
+    server_capabilities = server.lsp.lsp_initialize(params)
 
     assert isinstance(server_capabilities, InitializeResult)
 
 
-def test_to_lsp_name():
-    f_name = 'text_document__did_open'
-    name = 'textDocument/didOpen'
+def test_ignore_unknown_notification(client_server):
+    _, server = client_server
+
+    fn = server.lsp._execute_notification
+    server.lsp._execute_notification = Mock()
+
+    server.lsp._handle_notification("random/notification", None)
+    assert not server.lsp._execute_notification.called
+
+    # Remove mock
+    server.lsp._execute_notification = fn
 
-    assert to_lsp_name(f_name) == name
